==> task-3.33.1.tar.gz: task-3.33.1/docs/i18n/fr-FR/docusaurus-plugin-content-docs/current/community.md <==
---
slug: /community/
sidebar_position: 9
---

# Communauté

Certains travaux d'amélioration de l'écosystème Task sont réalisés par la communauté, que ce soit des méthodes d'installation ou des intégrations avec l'éditeur de code. Moi (l'auteur) suis reconnaissant envers tout le monde qui m'aide à améliorer l'expérience globale.

## Traductions

Nous utilisons [Crowdin](https://crowdin.com/project/taskfile) pour traduire nos documents.

## Intégrations

Un grand nombre de nos intégrations sont apportées et maintenues par la communauté. Vous pouvez voir la liste complète des intégrations de la communauté [ici](/integrations#community-integrations).

## Méthodes d'installation

Certaines méthodes d'installation sont maintenues par un tiers :

- [Actions GitHub](https://github.com/arduino/setup-task) par [@arduino](https://github.com/arduino)
- [AUR](https://aur.archlinux.org/packages/go-task-bin) par [@carlsmedstad](https://github.com/carlsmedstad)
- [Scoop](https://github.com/ScoopInstaller/Main/blob/master/bucket/task.json)
- [Fedora](https://packages.fedoraproject.org/pkgs/golang-github-task/go-task/)
- [NixOS](https://github.com/NixOS/nixpkgs/blob/master/pkgs/development/tools/go-task/default.nix)
- [Conda](https://github.com/conda-forge/go-task-feedstock/)

## Plus d’infos

Aussi, merci à tous les [contributeurs](https://github.com/go-task/task/graphs/contributors), [contributeurs financiers](https://opencollective.com/task), tous ceux qui [ont signalé des bugs](https://github.com/go-task/task/issues?q=is%3Aissue) et [ont répondu aux questions](https://github.com/go-task/task/discussions).

Si vous voyez quelque chose qui manque dans ce document, veuillez soumettre une pull request.

==> task-3.34.1.tar.gz: task-3.34.1/docs/i18n/fr-FR/docusaurus-plugin-content-docs/current/community.md <==
---
slug: /community/
sidebar_position: 9
---

# Communauté

Certains travaux d'amélioration de l'écosystème Task sont réalisés par la communauté, que ce soit des méthodes d'installation ou des intégrations avec l'éditeur de code. Moi (l'auteur) suis reconnaissant envers tout le monde qui m'aide à améliorer l'expérience globale.

## Traductions

Nous utilisons [Crowdin](https://crowdin.com/project/taskfile) pour traduire nos documents.

## Intégrations

Un grand nombre de nos intégrations sont apportées et maintenues par la communauté. Vous pouvez voir la liste complète des intégrations de la communauté [ici](/integrations#community-integrations).

## Méthodes d'installation

Certaines méthodes d'installation sont maintenues par un tiers :

- [GitHub Actions](https://github.com/arduino/setup-task) by @arduino
- [AUR](https://aur.archlinux.org/packages/go-task-bin) by @carlsmedstad
- [Scoop](https://github.com/ScoopInstaller/Main/blob/master/bucket/task.json)
- [Fedora](https://packages.fedoraproject.org/pkgs/golang-github-task/go-task/)
- [NixOS](https://github.com/NixOS/nixpkgs/blob/master/pkgs/development/tools/go-task/default.nix)
- [Conda](https://github.com/conda-forge/go-task-feedstock/)

## Plus d’infos

Aussi, merci à tous les [contributeurs](https://github.com/go-task/task/graphs/contributors), [contributeurs financiers](https://opencollective.com/task), tous ceux qui [ont signalé des bugs](https://github.com/go-task/task/issues?q=is%3Aissue) et [ont répondu aux questions](https://github.com/go-task/task/discussions).

Si vous voyez quelque chose qui manque dans ce document, veuillez soumettre une pull request.
